import { Component, EventEmitter, Input, NgModule, OnInit, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

import { LightboxModule } from 'primeng/components/lightbox/lightbox';
import { EditorModule } from 'primeng/components/editor/editor';

import { FileInputModule } from '../fileInput';
import { GlxSharedModule } from '../kernel/shared.module';

import { ChatItem } from './components/chatItem';
import { ChatNewMessage } from './components/chatNewMessage';
import { ChatToolbar } from './components/chatToolbar';
import { ChatHistory } from './components/chatHistory';
import { ChatSidebar } from './components/chatSidebar';

import { DefaultOptions } from './defaultOptions';
import { NewMessageStatus } from './components/chatNewMessage/newMessageStatus';

/**
 * Переписка по любой сущности
 */
@Component({
    selector: 'glx-chat-system',
    styleUrls: ['./chatSystem.scss'],
    templateUrl: './chatSystem.html'
})

export class ChatSystem implements OnInit {
    /**
     * Сообщения
     */
    @Input() data: any;
    /**
     * Опции
     * @type {any}
     */
    @Input() options: any = DefaultOptions;
    /**
     * Каналы
     */
    @Input() channels: any;
    /**
     * Активный канал
     */
    @Input() activeChannel: any;
    /**
     * ID текущего пользователя, для того чтобы понять свои или чужие сообщения
     */
    @Input() user_id: any;

    /**
     * Статус отправки нового сообщения
     */
    @Input() newMessageStatus: NewMessageStatus;
    /**
     * Ошибка отправки нового сообщения
     */
    @Input() newMessageError: string;

    /**
     * Новое сообщение
     * @type {EventEmitter<any>}
     */
    @Output() newMessage: EventEmitter<any> = new EventEmitter();
    /**
     * Смена канала
     * @type {EventEmitter<any>}
     */
    @Output() changeChannel: EventEmitter<any> = new EventEmitter();

    /**
     * Конструктор
     */
    constructor() {
    }

    /**
     * Инициализация
     */
    ngOnInit() {
        this.initChannels();
    }

    /**
     * Инициализация канала
     */
    initChannels() {
        if (!this.activeChannel && this.channels && this.channels.length > 0 && this.channels[0].code) {
            this.activeChannel = this.channels[0].code;
        }
    }

    /**
     * Событие добавления нового сообщения
     * @param event
     */
    newMessageHandler(event) {
        this.newMessage.emit(event);
    }

    /**
     * Событие смены канала сообщений
     * @param event
     */
    changeChannelHandler(event) {
        if (this.activeChannel !== event.code) {
            this.activeChannel = event.code;
            this.changeChannel.emit(event);
        }
    }
}

@NgModule({
    imports: [CommonModule, FormsModule, FileInputModule, GlxSharedModule, LightboxModule, EditorModule],
    exports: [ChatSystem, ChatItem, ChatNewMessage, ChatToolbar, ChatHistory, ChatSidebar],
    declarations: [ChatSystem, ChatItem, ChatNewMessage, ChatToolbar, ChatHistory, ChatSidebar]
})

export class ChatSystemModule {
}
