import { Component, Input, OnInit } from '@angular/core';
import { FileUtilities } from '../../../kernel/utilities/file.utilities';

/**
 * Просмотр сообщения
 */
@Component({
    selector: 'glx-chat-item',
    styleUrls: ['./chatItem.scss'],
    templateUrl: './chatItem.html'
})

export class ChatItem implements OnInit {
    /**
     * Мое или не мое сообщение
     * @type {boolean}
     */
    @Input() myMessage: boolean = false;
    /**
     * Автор сообщения
     * @type {string}
     */
    @Input() author: string = '';
    /**
     * Картинка автора сообщения
     */
    @Input() authorImg: string;
    /**
     * Время сообщения
     */
    @Input() time: string;
    /**
     * Текст сообщения
     */
    @Input() message: string;
    /**
     * Вложения к сообщению
     */
    @Input() attachments: any;
    /**
     * Формат даты
     * @type {string}
     */
    @Input() dateFormat: string = 'dd.MM.yy';


    /**
     * Картинки для просмотра
     * @type {Array}
     */
    images: any[] = [];
    /**
     * Файлы из вложения
     * @type {Array}
     */
    files: any = [];

    /**
     * Конструктор
     * @param {FileUtilities} util
     */
    constructor(public util: FileUtilities) {
    }

    /**
     * Инициализация
     */
    ngOnInit() {
        this.sortAttachments();
    }

    /**
     * Сортировка приложенных файлов на картинки и файлы
     */
    sortAttachments() {
        this.images = [];
        this.files = [];
        if (this.attachments && this.attachments.length > 0) {
            const l = this.attachments.length;
            for (let i = 0; i < l; i++) {
                const el = this.attachments[i];
                if (el.thumbnail) {
                    this.images.push({
                        source: el.path,
                        thumbnail: el.thumbnail,
                        title: el.name
                    });
                } else {
                    this.files.push(el);
                }
            }
        }
    }

    /**
     * Получить иконку файла
     * @param name Имя файла
     * @returns {string} класс иконки
     */
    getIcon(name) {
        return this.util.getFileIconByName(name);
    }
}
