import { Component, EventEmitter, Input, Output } from '@angular/core';

@Component({
    selector: 'glx-contract-operations',
    styleUrls: ['./contractOperations.scss'],
    templateUrl: './contractOperations.html'
})

export class ContractOperations {
    @Input() data: any;
    @Input() lang: any;
    @Input() options: any;

    displayPayment: boolean = false;
    needPay: boolean = false;
    paymentDetail: any;
    sum: number = 0;
    maxSum: number = 0;

    @Output() onPayment: EventEmitter<any> = new EventEmitter();

    constructor() {
    }

    pay(detail) {
        this.paymentDetail = detail;
        this.displayPayment = true;
        this.countSum();
    }

    payType(event, type) {
        if (this.sum > this.maxSum) {
            this.sum = this.maxSum;
        }
        this.displayPayment = false;

        this.onPayment.emit({
            originalEvent: event,
            payment: this.paymentDetail,
            type: type,
            sum: this.sum
        });
    }

    private countSum() {
        const allSum: number = +this.paymentDetail.sum;
        let paidSum: number = 0;
        if (this.paymentDetail.payments && this.paymentDetail.payments.length > 0) {
            for (let i = 0; i < this.paymentDetail.payments.length; i++) {
                const payment = this.paymentDetail.payments[i];
                paidSum += +payment.sum;
            }
        }

        this.maxSum = Number((allSum - paidSum).toFixed(2));
        if (this.maxSum > 0) {
            this.needPay = true;
        }
        this.sum = this.maxSum;
    }

    formInvalid() {
        return this.sum > this.maxSum || this.sum <= 0 || this.sum === undefined || this.sum === null;
    }
}
