import { Pipe, PipeTransform } from '@angular/core';
import * as moment from 'moment';
import 'moment/locale/ru';

/**
 * Форматирование даты в заданный формат с поддержкой moment.js
 */
@Pipe({
    name: 'datex'
})

export class DatexPipe implements PipeTransform {
    /**
     * Трансформирует строку содержащую дату(время) в нужный формат
     * @param value Строка с датой
     * @param {string} format Необходимый формат
     * @returns {string} Дата в нужном формате
     */
    transform(value: any, format: string = ''): string {
        // Try and parse the passed value.
        const momentDate = moment(value);

        // If moment didn't understand the value, return it unformatted.
        if (!momentDate.isValid()) {
            return value;
        }

        // Otherwise, return the date formatted as requested.
        return momentDate.format(format);
    }
}
