import { Injectable } from '@angular/core';
import { Http, Response, RequestOptions, Headers } from '@angular/http';
import { AuthHttp } from 'angular2-jwt';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/catch';
import 'rxjs/add/observable/throw';
import 'rxjs/add/operator/publishReplay';

/**
 * Простой сервис для API с кешированием получаемых данных
 */

@Injectable()
export class CommonService {

    private apiUrl: string = '/bitrix/vuz/api/';
    private _cache: any = {};
    private _cacheDate: any = {};
    private secure: boolean = false;
    private http: any;

    constructor(private commonHttp: Http, private authHttp: AuthHttp) {
        this.http = this.commonHttp;
    }

    public setUrl(url: string) {
        this.apiUrl = url;
    }

    public useAuth(b: boolean) {
        this.secure = b;
        if (this.secure) {
            this.http = this.authHttp;
        } else {
            this.http = this.commonHttp;
        }
    }

    clearCache(key?: string) {
        if (key) {
            if (this._cache.hasOwnProperty(key)) {
                delete this._cache[key];
                delete this._cacheDate[key];
            }
        } else {
            this._cache = {};
            this._cacheDate = {};
        }
    }

    public get(name: string): Observable<any> {
        if (!this._cache.hasOwnProperty(name)) {
            const url = this.apiUrl + name + '/';
            this._cacheDate[name] = new Date();

            this._cache[name] = this.http
                .get(url)
                .map((res: Response) => res.json())
                .publishReplay(1)
                .refCount()
                .catch(this._handleError);
        }
        return this._cache[name];
    }

    public getById(name: string, id: number | string): Observable<any> {
        const key = name + '_' + id;
        if (!this._cache.hasOwnProperty(key)) {
            const url = this.apiUrl + name + '/' + id + '/';
            this._cacheDate[key] = new Date();

            this._cache[key] = this.http
                .get(url)
                .map((res: Response) => res.json())
                .publishReplay(1)
                .refCount()
                .catch(this._handleError);
        }
        return this._cache[key];
    }

    public put(name: string, data: any, id?: number | string): Observable<any> {
        const headers = new Headers({'Content-Type': 'application/json'});
        const options = new RequestOptions({headers: headers});

        let url = '';
        if (id) {
            url = this.apiUrl + name + '/' + id + '/';
        } else {
            url = this.apiUrl + name + '/';
        }


        this.clearCache(name);

        return this.http
            .put(url, data, options)
            .map((res: Response) => res.json())
            .catch(this._handleError);

    }

    public post(name: string, data: any): Observable<any> {
        const headers = new Headers({'Content-Type': 'application/json'});
        const options = new RequestOptions({headers: headers});
        const url = this.apiUrl + name + '/';

        this.clearCache(name);

        return this.http
            .post(url, data, options)
            .map((res: Response) => res.json())
            .catch(this._handleError);
    }

    public delete(name: string, id: number | string): Observable<any> {
        const url = this.apiUrl + name + '/' + id + '/';

        this.clearCache(name + '_' + id);

        return this.http
            .delete(url)
            .map((res: Response) => res.json())
            .catch(this._handleError);

    }

    private _handleError(error: any) {
        console.error(error);
        this.clearCache();
        if (error instanceof Response) {
            return Observable.throw(error.json().error || error.json() || 'Server error');
        }
        return Observable.throw(error || 'Server error');
    }
}
