import { Injectable } from '@angular/core';
import { Http, Response, RequestOptions, Headers } from '@angular/http';
import { Observable } from 'rxjs/Observable';
import { Profile } from '../models/profile.model';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/do';
import 'rxjs/add/operator/catch';
import 'rxjs/add/observable/throw';
import 'rxjs/add/operator/publishReplay';

@Injectable()
export class ProfileService {

    private apiUrl: string = '/bitrix/vuz/api/profile/';
    _current: Observable<Profile> = null;
    _role: string = null;
    current: Profile = new Profile();

    constructor(private http: Http) {
    }

    clearCache() {
        this._current = null;
        this._role = null;
        this.current = null;
    }

    setUrl(url: string) {
        this.apiUrl = url;
    }

    getCurrent(): Observable<Profile> {
        if (!this._current) {
            this._current = this.http.get(this.apiUrl + 'current')
                .map((res: Response) => res.json())
                .do((profile: Profile) => {
                    this._role = profile.role;
                    this.current = profile;
                })
                .publishReplay(1)
                .refCount()
                .catch(this._handleError);
        }
        return this._current;
    }

    searchStudents(filter: any): Observable<any> {
        const headers = new Headers({'Content-Type': 'application/json'});
        const options = new RequestOptions({headers: headers});

        return this.http
            .post('/bitrix/vuz/api/profiles/students', filter, options)
            .map((response: Response) => {
                return response.json();
            })
            .catch(this._handleError);
    }

    searchEmployees(filter: any): Observable<any> {
        const headers = new Headers({'Content-Type': 'application/json'});
        const options = new RequestOptions({headers: headers});

        return this.http
            .post('/bitrix/vuz/api/profiles/employees', filter, options)
            .map((response: Response) => {
                return response.json();
            })
            .catch(this._handleError);
    }

    get(id: number): Observable<any> {
        return this.http
            .get(this.apiUrl + 'view/' + id)
            .map((response: Response) => {
                return response.json();
            })
            .catch(this._handleError);
    }

    getRole(): string {
        if (!this._role) {
            this.getCurrent()
                .subscribe(
                    data => {
                        return data.role;
                    },
                    error => {
                        console.error(error);
                        return null;
                    });
        } else {
            return this._role;
        }
    }

    public getType(): Observable<any> {
        return this.http
            .get(this.apiUrl + 'type')
            .map((response: Response) => {
                return response.json();
            })
            .catch(this._handleError);
    }


    private _handleError(error: any) {
        console.error(error);
        if (error instanceof Response) {
            return Observable.throw(error.json().error || error.json() || 'Server error');
        }
        return Observable.throw(error || 'Server error');
    }
}
