import { Injectable } from '@angular/core';
import { Headers, Http, RequestOptions, Response } from '@angular/http';
import { User } from '../models/user.model';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/do';
import 'rxjs/add/operator/catch';
import 'rxjs/add/observable/throw';
import 'rxjs/add/operator/publishReplay';

@Injectable()
export class UserService {

    private apiUrl: string = '/bitrix/vuz/api/user';

    constructor(private http: Http) {
    }

    setUrl(url: string) {
        this.apiUrl = url;
    }

    getCurrent(): Observable<User> {
        return this.http.get(this.apiUrl + '/')
            .map((res: Response) => res.json())
            .catch(this._handleError);
    }

    get(id: number): Observable<any> {
        return this.http
            .get(this.apiUrl + '/' + id)
            .map((res: Response) => res.json())
            .catch(this._handleError);
    }

    getBx(id: number): Observable<any> {
        return this.http
            .get(this.apiUrl + '/bx/' + id)
            .map((res: Response) => res.json())
            .catch(this._handleError);
    }

    search(filter: any): Observable<any> {
        const headers = new Headers({'Content-Type': 'application/json'});
        const options = new RequestOptions({headers: headers});

        return this.http
            .post(this.apiUrl + '/search', filter, options)
            .map((res: Response) => res.json())
            .catch(this._handleError);
    }

    searchEmployee(filter: any): Observable<any> {
        const headers = new Headers({'Content-Type': 'application/json'});
        const options = new RequestOptions({headers: headers});

        return this.http
            .post(this.apiUrl + '/search/employee', filter, options)
            .map((res: Response) => res.json())
            .catch(this._handleError);
    }

    private _handleError(error: any) {
        console.error(error);
        if (error instanceof Response) {
            return Observable.throw(error.json().error || error.json() || 'Server error');
        }
        return Observable.throw(error || 'Server error');
    }
}
