import { Injectable } from '@angular/core';

/**
 * Вспомогательный класс для работы с файлами
 */
@Injectable()
export class FileUtilities {
    /**
     * Получить Font Awesome класс иконки для файла по его имени
     * @param {string} name Имя файла
     * @returns {string} Класс иконки Font Awesome
     */
    getFileIconByName(name: string) {
        switch (this.getFileExtensionByName(name).toLowerCase()) {
            case '.jpg':
            case '.jpeg':
            case '.png':
            case '.bmp':
            case '.gif':
            case '.svg':
                return 'fa-file-image-o';
            case '.zip':
            case '.rar':
            case '.7z':
            case '.gz':
            case '.jar':
                return 'fa-file-archive-o';
            case '.pdf':
                return 'fa-file-pdf-o';
            case '.xls':
            case '.xlsx':
            case '.csv':
            case '.dbf':
            case '.ods':
                return 'fa-file-excel-o';
            case '.doc':
            case '.docx':
            case '.odt':
                return 'fa-file-word-o';
            case '.ppt':
            case '.pptx':
            case '.odp':
                return 'fa-file-powerpoint-o';
            case '.txt':
                return 'fa-file-text-o';
            case '.avi':
            case '.mkv':
                return 'fa-file-video-o';
            case '.mp3':
            case '.wav':
                return 'fa-file-audio-o';
            case '.xml':
            case '.json':
            case '.html':
            case '.htm':
            case '.js':
            case '.php':
            case '.c':
            case '.cpp':
            case '.h':
                return 'fa-file-code-o';
            default:
                return 'fa-file-text-o';
        }
    }

    /**
     * Получить Font Awesome класс иконки для файла
     * @param {File} file Файл
     * @returns {string} Класс иконки Font Awesome
     */
    getFileIcon(file: File) {
        if (this.isImage(file)) {
            return 'fa-file-image-o';
        }
        if (this.isVideo(file)) {
            return 'fa-file-video-o';
        }
        if (this.isAudio(file)) {
            return 'fa-file-audio-o';
        }

        switch (this.getFileExtension(file).toLowerCase()) {
            case '.zip':
            case '.rar':
            case '.7z':
            case '.gz':
            case '.jar':
                return 'fa-file-archive-o';
            case '.pdf':
                return 'fa-file-pdf-o';
            case '.xls':
            case '.xlsx':
            case '.csv':
            case '.dbf':
            case '.ods':
                return 'fa-file-excel-o';
            case '.doc':
            case '.docx':
            case '.odt':
                return 'fa-file-word-o';
            case '.ppt':
            case '.pptx':
            case '.odp':
                return 'fa-file-powerpoint-o';
            case '.txt':
                return 'fa-file-text-o';
            case '.avi':
                return 'fa-file-video-o';
            case '.mp3':
                return 'fa-file-audio-o';
            case '.xml':
            case '.json':
            case '.html':
            case '.htm':
            case '.js':
            case '.php':
            case '.c':
            case '.cpp':
            case '.h':
                return 'fa-file-code-o';
            default:
                return 'fa-file-text-o';
        }
    }

    /**
     * Получить расширение файла
     * @param {File} file Файл
     * @returns {string} Расширение
     */
    getFileExtension(file: File): string {
        return '.' + file.name.split('.').pop();
    }

    /**
     * Получить расширение файла по его имени
     * @param {string} name Имя файла
     * @returns {string} Расширение файла
     */
    getFileExtensionByName(name: string): string {
        return '.' + name.split('.').pop();
    }

    /**
     * Проверяет, является ли файл изображением
     * @param {File} file
     * @returns {boolean}
     */
    isImage(file: File): boolean {
        return /^image\//.test(file.type);
    }

    /**
     * Проверяет, является ли файл видеофайлом
     * @param {File} file
     * @returns {boolean}
     */
    isVideo(file: File): boolean {
        return /^video\//.test(file.type);
    }

    /**
     * Проверяет, является ли файл звуковыйм файлов
     * @param {File} file
     * @returns {boolean}
     */
    isAudio(file: File): boolean {
        return /^audio\//.test(file.type);
    }
}
