import { NgModule, Component, OnInit, OnChanges, Input, HostListener, AfterViewInit, SimpleChanges } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';
import { OverlayPanelModule } from 'primeng/components/overlaypanel/overlaypanel';

declare let $: any;

@Component({
    selector: 'glx-top-menu-bx',
    templateUrl: './topMenuBx.html',
    styleUrls: ['./topMenuBx.scss']
})
export class TopMenuBx implements OnInit, OnChanges, AfterViewInit {
    @Input() items: any[] = [];
    @Input() moreBtnText: string = 'Еще';
    activeMenuId: number = 0;
    showMore: boolean = true;
    moreBtnWidth: number = 0;

    constructor() {
    }

    ngOnInit() {
        this.setAllShown();
    }

    ngOnChanges(changes: SimpleChanges) {
        if (changes.items) {
            this.setAllShown();
            setTimeout(() => {
                this.calcSizes();
                this.calcMenu();
            });
        }
    }

    ngAfterViewInit() {
        this.calcSizes();
        this.calcMenu();
    }

    setAllShown() {
        for (let j = 0; j < this.items.length; j++) {
            this.items[j].shown = true;
        }
    }

    calcSizes() {
        for (let j = 0; j < this.items.length; j++) {
            if (this.items[j].enabled || this.items[j].enabled === 1) {
                this.items[j].width = $('#menu-top-item-' + j).width() + 50;
                if (j > 0) {
                    this.items[j].sumWidth = this.items[j].width + this.items[j - 1].sumWidth;
                } else {
                    this.items[j].sumWidth = this.items[j].width;
                }
                this.items[j].sumWidth = this.items[j].sumWidth > 0 ? this.items[j].sumWidth : 150;
            }
        }
        // считаем ширину кнопки Еще
        const elemMoreWidth = $('#menu-top-item-more').width();
        this.moreBtnWidth = elemMoreWidth > 0 ? elemMoreWidth + 8 : 100;
    }

    calcMenu() {
        let maxWidth: number, showMore = false;
        maxWidth = $('#menu-top').width() - this.moreBtnWidth;
        for (let j = 0; j < this.items.length; j++) {
            if (this.items[j].enabled || this.items[j].enabled === 1) {
                if (this.items[j].sumWidth >= maxWidth) {
                    showMore = true;
                    setTimeout(() => {
                        this.items[j].shown = false;
                    });
                } else {
                    showMore = false;
                    setTimeout(() => {
                        this.items[j].shown = true;
                    });

                }
            }
        }
        setTimeout(() => {
            this.showMore = showMore;
        });
    }

    @HostListener('window:resize', ['$event'])
    onResize() {
        this.calcMenu();
    }
}

@NgModule({
    imports: [CommonModule, RouterModule, OverlayPanelModule],
    exports: [TopMenuBx],
    declarations: [TopMenuBx]
})

export class TopMenuBxModule {
}
