import { Component, EventEmitter, Input, NgModule, OnInit, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';
import { FormsModule } from '@angular/forms';
import { User } from '../kernel/models/user.model';
import { DialogModule } from 'primeng/components/dialog/dialog';
import { InputMaskModule } from 'primeng/components/inputmask/inputmask';
import { GlxSharedModule } from '../kernel/shared.module';

import { PhotoInputModule } from '../photoInput/photoInput';

@Component({
    selector: 'glx-user-edit',
    styleUrls: ['./userEdit.scss'],
    templateUrl: './userEdit.html'
})

export class UserEdit implements OnInit {
    @Input() user: User;
    @Input() defaultImage: string = '';
    @Input() saving: string;
    @Input() options: any;
    _fields: any = {};
    snilsError: any = {};

    textPD: string;
    textPDDispay: boolean = false;

    @Output() onChange: EventEmitter<any> = new EventEmitter();

    constructor() {
    }

    ngOnInit() {
        if (this.user) {
            switch (this.user.profile.role) {
                case 'student':
                    this._fields = {
                        id: this.user.id,
                        profile: {
                            web: this.user.profile.web,
                            notes: this.user.profile.notes,
                            show_email: this.user.profile.show_email,
                            show_mobile: this.user.profile.show_mobile,
                            show_birthdate: this.user.profile.show_birthdate,
                            mobile: this.user.profile.mobile,
                        },
                        user: {
                            email_notify: this.user.email_notify,
                            password: '',
                            password_confirm: '',
                            snils: this.user.snils,
                        }
                    };
                    break;
                case 'employee':
                    this._fields = {
                        id: this.user.id,
                        profile: {
                            web: this.user.profile.web,
                            notes: this.user.profile.notes,
                            work_address: this.user.profile.work_address,
                            prof_notes: this.user.profile.prof_notes,
                            show_email: this.user.profile.show_email,
                            show_mobile: this.user.profile.show_mobile,
                            show_birthdate: this.user.profile.show_birthdate,
                            mobile: this.user.profile.mobile,
                        },
                        user: {
                            email_notify: this.user.email_notify,
                            password: '',
                            password_confirm: '',
                            snils: this.user.snils,
                        }
                    };
                    break;
            }
        }
    }

    onPhotoChange(event) {
        this._fields.photo = event.image;
    }

    save() {
        if (this.options.canChangeSnils && this.snilsError && this.snilsError.code && this.snilsError.code > 0) {
            return;
        }
        this.onChange.emit({fields: this._fields});
    }

    openPD() {
        this.textPD = this.options.textPD.replace('${fullname}', this.user.fullname);
        this.textPDDispay = true;
    }

    validateSnils(snils) {
        let result = false;
        this.snilsError = {};
        if (snils) {
            if (typeof snils === 'number') {
                snils = snils.toString();
            } else if (typeof snils !== 'string') {
                snils = '';
            }
            if (!snils.length) {
                this.snilsError.code = 1;
                this.snilsError.message = 'СНИЛС пуст';
            } else if (/[^0-9]/.test(snils)) {
                this.snilsError.code = 2;
                this.snilsError.message = 'СНИЛС может состоять только из цифр';
            } else if (snils.length !== 11) {
                this.snilsError.code = 3;
                this.snilsError.message = 'СНИЛС может состоять только из 11 цифр';
            } else {
                let sum = 0;
                for (let i = 0; i < 9; i++) {
                    sum += parseInt(snils[i], 10) * (9 - i);
                }
                let checkDigit = 0;
                if (sum < 100) {
                    checkDigit = sum;
                } else if (sum > 101) {
                    checkDigit = parseInt((sum % 101).toString(), 10);
                    if (checkDigit === 100) {
                        checkDigit = 0;
                    }
                }
                if (checkDigit === parseInt(snils.slice(-2), 10)) {
                    result = true;
                } else {
                    this.snilsError.code = 4;
                    this.snilsError.message = 'Неправильное контрольное число';
                }
            }
        } else {
            return true;
        }

        return result;
    }
}

@NgModule({
    imports: [CommonModule, RouterModule, PhotoInputModule, FormsModule, DialogModule, InputMaskModule, GlxSharedModule],
    exports: [UserEdit],
    declarations: [UserEdit]
})

export class UserEditModule {
}
